﻿using System.Collections.Generic;

namespace Eingabeverwaltung.Metamodell
{
    public class InductionConfig : IConfig
    {
        public readonly List<InductionCaseConfig> indCaseConfigs;
        public readonly SingleConfig indHypConfig;

        public InductionConfig(List<InductionCaseConfig> indCaseConfigs, SingleConfig indHypConfig)
        {
            this.indCaseConfigs = indCaseConfigs;
            this.indHypConfig = indHypConfig;
        }

        public int MaxPt()
        {
            int res = 0;
            foreach(InductionCaseConfig indCaseConfig in indCaseConfigs)
            {
                res += indCaseConfig.config.maxPt;
            }
            res += indHypConfig.maxPt;
            return res;
        }

        /// <summary>
        /// Finds and returns the config for the given constructor. Returns null if not able to find.
        /// </summary>
        /// <param name="c"></param>
        /// <returns></returns>
        public InductionCaseConfig GetIndCaseConfig(Constructor c)
        {
            foreach (InductionCaseConfig icC in indCaseConfigs)
                if (icC.indCase == c) return icC;
            return null;
        }

        public override string ToString()
        {
            string res = "";
            string tab = "    ";
            foreach (InductionCaseConfig icc in indCaseConfigs)
                res += tab + icc.ToString();
            res += tab + "IH: maxpt "+indHypConfig.maxPt+"\r\n";
            return res;
        }
    }
}
